@@ -252,9 +252,7 @@ func (c *giteaClient) CreateRelease(ctx *context.Context, body string) (string,
 	}
 
 	if release != nil {
-		if release.Note != "" {
-			body = release.Note
-		}
+		body = getReleaseNotes(release.Note, body, ctx.Config.Release.ReleaseNotesMode)
 		release, err = c.updateRelease(ctx, title, body, release.ID)
 		if err != nil {
 			return "", err
